@@ -45,7 +45,7 @@ LearnerSurvKaplan = R6Class("LearnerSurvKaplan",
                                              decorators = c("CoreStatistics", "ExoticStatistics"))
 
       # Define crank as the mean of the survival distribution
-      crank = as.numeric(sum(x[[1]]$x * c(x[[1]]$cdf[1], diff(x[[1]]$cdf))))
+      crank = -as.numeric(sum(x[[1]]$x * c(x[[1]]$cdf[1], diff(x[[1]]$cdf))))
 
       list(crank = rep(crank, task$nrow), distr = distr)
     }
